@@ -1,12 +1,13 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2017-06-17'; # DATE
-our $VERSION = '1.74'; # VERSION
+our $DATE = '2017-06-28'; # DATE
+our $VERSION = '1.75'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
 # use warnings; # already enabled by Mo
-use Log::Any::IfLOG '$log';
+use Log::ger;
+use Log::ger::LevelFromEnv;
 
 use List::Util qw(first);
 use Mo qw(build default);
@@ -171,11 +172,14 @@ sub hook_after_parse_argv {
 
     # set up log adapter
     if ($self->log) {
-        require Log::Any::Adapter;
-        Log::Any::Adapter->set(
+        require Log::ger::Output;
+        require Log::ger::Util;
+        my $str_level = $r->{log_level} // $self->log_level;
+        $Log::ger::Current_Level =
+            Log::ger::Util::numeric_level($str_level) // 3;
+        Log::ger::Output->set(
             'Screen',
-            min_level => $r->{log_level} // $self->log_level,
-            formatter => sub { $self->program_name . ": $_[1]" },
+            formatter => sub { $self->program_name . ": $_[0]" },
         );
     }
 }
@@ -364,11 +368,11 @@ sub hook_after_get_meta {
             handler => sub {
                 my ($go, $val, $r) = @_;
                 if ($val) {
-                    $log->debugf("[pericmd] Dry-run mode is activated");
+                    log_debug("[pericmd] Dry-run mode is activated");
                     $r->{dry_run} = 1;
                     #$ENV{VERBOSE} = 1;
                 } else {
-                    $log->debugf("[pericmd] Dry-run mode is deactivated");
+                    log_debug("[pericmd] Dry-run mode is deactivated");
                     $r->{dry_run} = 0;
                 }
             },
@@ -482,7 +486,7 @@ sub action_call {
 
     my %extra;
     if ($r->{send_argv}) {
-        $log->tracef("[pericmd] Sending argv to server: %s", $extra{argv});
+        log_trace("[pericmd] Sending argv to server: %s", $extra{argv});
         $extra{argv} = $r->{orig_argv};
     } else {
         my %extra_args;
@@ -495,9 +499,9 @@ sub action_call {
     my $url = $r->{subcommand_data}{url};
 
     # currently we don't log args because it's potentially large
-    $log->tracef("[pericmd] Riap request: action=call, url=%s", $url);
+    log_trace("[pericmd] Riap request: action=call, url=%s", $url);
 
-    #$log->tracef("TMP: extra=%s", \%extra);
+    #log_trace("TMP: extra=%s", \%extra);
 
     # setup output progress indicator
     if ($r->{meta}{features}{progress}) {
@@ -523,7 +527,7 @@ Perinci::CmdLine::Lite - A Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.74 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2017-06-17.
+This document describes version 1.75 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2017-06-28.
 
 =head1 SYNOPSIS
 
@@ -676,13 +680,12 @@ All the attributes of L<Perinci::CmdLine::Base>, plus:
 
 =head2 log => bool (default: from env or 0)
 
-Whether to enable logging. This currently means setting up L<Log::Any::Adapter>
-to display logging (set in C<hook_after_parse_argv>, so tab completion skips
-this step). To produce log, you use L<Log::Any> in your code.
+Whether to enable logging. This currently means calling L<Log::ger::Output> to
+set logging output to C<Screen> (set in C<hook_after_parse_argv>, so tab
+completion skips this step). To produce log, you use L<Log::ger> in your code.
 
-The default is off. If you set LOG=1 or LOG_LEVEL or TRACE/DEBUG/VERBOSE/QUIET,
-then the default will be on. It defaults to off if you set LOG=0 or
-LOG_LEVEL=off.
+The default is off. If you set LOG_LEVEL or TRACE/DEBUG/VERBOSE/QUIET, then the
+default will be on. It defaults to off if you set LOG_LEVEL=off.
 
 =head2 log_level => str (default: from env, or 'warning')
 
